# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: arg_services/nlp/v1/nlp.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='arg_services/nlp/v1/nlp.proto',
  package='arg_services.nlp.v1',
  syntax='proto3',
  serialized_options=b'\n&de.uni_trier.recap.arg_services.nlp.v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x61rg_services/nlp/v1/nlp.proto\x12\x13\x61rg_services.nlp.v1\"\xb3\x01\n\tNlpConfig\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x13\n\x0bspacy_model\x18\x02 \x01(\t\x12=\n\x10\x65mbedding_models\x18\x03 \x03(\x0b\x32#.arg_services.nlp.v1.EmbeddingModel\x12@\n\x11similarity_method\x18\x04 \x01(\x0e\x32%.arg_services.nlp.v1.SimilarityMethod\"z\n\x13SimilaritiesRequest\x12.\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1e.arg_services.nlp.v1.NlpConfig\x12\x33\n\x0btext_tuples\x18\x02 \x03(\x0b\x32\x1e.arg_services.nlp.v1.TextTuple\",\n\x14SimilaritiesResponse\x12\x14\n\x0csimilarities\x18\x01 \x03(\x01\")\n\tTextTuple\x12\r\n\x05text1\x18\x01 \x01(\t\x12\r\n\x05text2\x18\x02 \x01(\t\"\xd9\x01\n\rDocBinRequest\x12.\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1e.arg_services.nlp.v1.NlpConfig\x12\r\n\x05texts\x18\x02 \x03(\t\x12\x12\n\nattributes\x18\x03 \x03(\t\x12\x15\n\rno_attributes\x18\x04 \x01(\x08\x12\r\n\x05pipes\x18\x05 \x03(\t\x12\x10\n\x08no_pipes\x18\x06 \x01(\x08\x12=\n\x10\x65mbedding_levels\x18\x07 \x03(\x0e\x32#.arg_services.nlp.v1.EmbeddingLevel\" \n\x0e\x44ocBinResponse\x12\x0e\n\x06\x64ocbin\x18\x01 \x01(\x0c\"\x8e\x01\n\x0eVectorsRequest\x12.\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1e.arg_services.nlp.v1.NlpConfig\x12\r\n\x05texts\x18\x02 \x03(\t\x12=\n\x10\x65mbedding_levels\x18\x03 \x03(\x0e\x32#.arg_services.nlp.v1.EmbeddingLevel\"G\n\x0fVectorsResponse\x12\x34\n\x07vectors\x18\x01 \x03(\x0b\x32#.arg_services.nlp.v1.VectorResponse\"\x9c\x01\n\x0eVectorResponse\x12-\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x1b.arg_services.nlp.v1.Vector\x12+\n\x06tokens\x18\x02 \x03(\x0b\x32\x1b.arg_services.nlp.v1.Vector\x12.\n\tsentences\x18\x03 \x03(\x0b\x32\x1b.arg_services.nlp.v1.Vector\"\x18\n\x06Vector\x12\x0e\n\x06vector\x18\x01 \x03(\x01\"\x8b\x01\n\x0e\x45mbeddingModel\x12\x36\n\nmodel_type\x18\x01 \x01(\x0e\x32\".arg_services.nlp.v1.EmbeddingType\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12-\n\x07pooling\x18\x03 \x01(\x0e\x32\x1c.arg_services.nlp.v1.Pooling*\xe0\x02\n\x10SimilarityMethod\x12!\n\x1dSIMILARITY_METHOD_UNSPECIFIED\x10\x00\x12\x1c\n\x18SIMILARITY_METHOD_COSINE\x10\x01\x12%\n!SIMILARITY_METHOD_DYNAMAX_JACCARD\x10\x02\x12%\n!SIMILARITY_METHOD_MAXPOOL_JACCARD\x10\x03\x12\"\n\x1eSIMILARITY_METHOD_DYNAMAX_DICE\x10\x04\x12$\n SIMILARITY_METHOD_DYNAMAX_OTSUKA\x10\x05\x12\x19\n\x15SIMILARITY_METHOD_WMD\x10\x06\x12\x1a\n\x16SIMILARITY_METHOD_EDIT\x10\x07\x12\x1d\n\x19SIMILARITY_METHOD_JACCARD\x10\x08\x12\x1d\n\x19SIMILARITY_METHOD_ANGULAR\x10\t*\x8a\x01\n\x0e\x45mbeddingLevel\x12\x1f\n\x1b\x45MBEDDING_LEVEL_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x45MBEDDING_LEVEL_DOCUMENT\x10\x01\x12\x1a\n\x16\x45MBEDDING_LEVEL_TOKENS\x10\x02\x12\x1d\n\x19\x45MBEDDING_LEVEL_SENTENCES\x10\x03*\xc6\x01\n\x07Pooling\x12\x17\n\x13POOLING_UNSPECIFIED\x10\x00\x12\x10\n\x0cPOOLING_MEAN\x10\x01\x12\x0f\n\x0bPOOLING_MAX\x10\x02\x12\x0f\n\x0bPOOLING_MIN\x10\x03\x12\x0f\n\x0bPOOLING_SUM\x10\x04\x12\x11\n\rPOOLING_FIRST\x10\x05\x12\x10\n\x0cPOOLING_LAST\x10\x06\x12\x12\n\x0ePOOLING_MEDIAN\x10\x07\x12\x11\n\rPOOLING_GMEAN\x10\x08\x12\x11\n\rPOOLING_HMEAN\x10\t*{\n\rEmbeddingType\x12\x1e\n\x1a\x45MBEDDING_TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x45MBEDDING_TYPE_SPACY\x10\x01\x12\x16\n\x12\x45MBEDDING_TYPE_USE\x10\x02\x12\x18\n\x14\x45MBEDDING_TYPE_SBERT\x10\x03\x32\x9a\x02\n\nNlpService\x12Q\n\x06\x44ocBin\x12\".arg_services.nlp.v1.DocBinRequest\x1a#.arg_services.nlp.v1.DocBinResponse\x12T\n\x07Vectors\x12#.arg_services.nlp.v1.VectorsRequest\x1a$.arg_services.nlp.v1.VectorsResponse\x12\x63\n\x0cSimilarities\x12(.arg_services.nlp.v1.SimilaritiesRequest\x1a).arg_services.nlp.v1.SimilaritiesResponseB(\n&de.uni_trier.recap.arg_services.nlp.v1b\x06proto3'
)

_SIMILARITYMETHOD = _descriptor.EnumDescriptor(
  name='SimilarityMethod',
  full_name='arg_services.nlp.v1.SimilarityMethod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_COSINE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_DYNAMAX_JACCARD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_MAXPOOL_JACCARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_DYNAMAX_DICE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_DYNAMAX_OTSUKA', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_WMD', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_EDIT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_JACCARD', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIMILARITY_METHOD_ANGULAR', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1249,
  serialized_end=1601,
)
_sym_db.RegisterEnumDescriptor(_SIMILARITYMETHOD)

SimilarityMethod = enum_type_wrapper.EnumTypeWrapper(_SIMILARITYMETHOD)
_EMBEDDINGLEVEL = _descriptor.EnumDescriptor(
  name='EmbeddingLevel',
  full_name='arg_services.nlp.v1.EmbeddingLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_LEVEL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_LEVEL_DOCUMENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_LEVEL_TOKENS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_LEVEL_SENTENCES', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1604,
  serialized_end=1742,
)
_sym_db.RegisterEnumDescriptor(_EMBEDDINGLEVEL)

EmbeddingLevel = enum_type_wrapper.EnumTypeWrapper(_EMBEDDINGLEVEL)
_POOLING = _descriptor.EnumDescriptor(
  name='Pooling',
  full_name='arg_services.nlp.v1.Pooling',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='POOLING_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_MEAN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_MAX', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_MIN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_SUM', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_FIRST', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_LAST', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_MEDIAN', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_GMEAN', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POOLING_HMEAN', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1745,
  serialized_end=1943,
)
_sym_db.RegisterEnumDescriptor(_POOLING)

Pooling = enum_type_wrapper.EnumTypeWrapper(_POOLING)
_EMBEDDINGTYPE = _descriptor.EnumDescriptor(
  name='EmbeddingType',
  full_name='arg_services.nlp.v1.EmbeddingType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_TYPE_SPACY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_TYPE_USE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMBEDDING_TYPE_SBERT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1945,
  serialized_end=2068,
)
_sym_db.RegisterEnumDescriptor(_EMBEDDINGTYPE)

EmbeddingType = enum_type_wrapper.EnumTypeWrapper(_EMBEDDINGTYPE)
SIMILARITY_METHOD_UNSPECIFIED = 0
SIMILARITY_METHOD_COSINE = 1
SIMILARITY_METHOD_DYNAMAX_JACCARD = 2
SIMILARITY_METHOD_MAXPOOL_JACCARD = 3
SIMILARITY_METHOD_DYNAMAX_DICE = 4
SIMILARITY_METHOD_DYNAMAX_OTSUKA = 5
SIMILARITY_METHOD_WMD = 6
SIMILARITY_METHOD_EDIT = 7
SIMILARITY_METHOD_JACCARD = 8
SIMILARITY_METHOD_ANGULAR = 9
EMBEDDING_LEVEL_UNSPECIFIED = 0
EMBEDDING_LEVEL_DOCUMENT = 1
EMBEDDING_LEVEL_TOKENS = 2
EMBEDDING_LEVEL_SENTENCES = 3
POOLING_UNSPECIFIED = 0
POOLING_MEAN = 1
POOLING_MAX = 2
POOLING_MIN = 3
POOLING_SUM = 4
POOLING_FIRST = 5
POOLING_LAST = 6
POOLING_MEDIAN = 7
POOLING_GMEAN = 8
POOLING_HMEAN = 9
EMBEDDING_TYPE_UNSPECIFIED = 0
EMBEDDING_TYPE_SPACY = 1
EMBEDDING_TYPE_USE = 2
EMBEDDING_TYPE_SBERT = 3



_NLPCONFIG = _descriptor.Descriptor(
  name='NlpConfig',
  full_name='arg_services.nlp.v1.NlpConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='arg_services.nlp.v1.NlpConfig.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spacy_model', full_name='arg_services.nlp.v1.NlpConfig.spacy_model', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='embedding_models', full_name='arg_services.nlp.v1.NlpConfig.embedding_models', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='similarity_method', full_name='arg_services.nlp.v1.NlpConfig.similarity_method', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=234,
)


_SIMILARITIESREQUEST = _descriptor.Descriptor(
  name='SimilaritiesRequest',
  full_name='arg_services.nlp.v1.SimilaritiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='arg_services.nlp.v1.SimilaritiesRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_tuples', full_name='arg_services.nlp.v1.SimilaritiesRequest.text_tuples', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=358,
)


_SIMILARITIESRESPONSE = _descriptor.Descriptor(
  name='SimilaritiesResponse',
  full_name='arg_services.nlp.v1.SimilaritiesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='similarities', full_name='arg_services.nlp.v1.SimilaritiesResponse.similarities', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=360,
  serialized_end=404,
)


_TEXTTUPLE = _descriptor.Descriptor(
  name='TextTuple',
  full_name='arg_services.nlp.v1.TextTuple',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text1', full_name='arg_services.nlp.v1.TextTuple.text1', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text2', full_name='arg_services.nlp.v1.TextTuple.text2', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=406,
  serialized_end=447,
)


_DOCBINREQUEST = _descriptor.Descriptor(
  name='DocBinRequest',
  full_name='arg_services.nlp.v1.DocBinRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='arg_services.nlp.v1.DocBinRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='texts', full_name='arg_services.nlp.v1.DocBinRequest.texts', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='arg_services.nlp.v1.DocBinRequest.attributes', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_attributes', full_name='arg_services.nlp.v1.DocBinRequest.no_attributes', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pipes', full_name='arg_services.nlp.v1.DocBinRequest.pipes', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_pipes', full_name='arg_services.nlp.v1.DocBinRequest.no_pipes', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='embedding_levels', full_name='arg_services.nlp.v1.DocBinRequest.embedding_levels', index=6,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=450,
  serialized_end=667,
)


_DOCBINRESPONSE = _descriptor.Descriptor(
  name='DocBinResponse',
  full_name='arg_services.nlp.v1.DocBinResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='docbin', full_name='arg_services.nlp.v1.DocBinResponse.docbin', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=669,
  serialized_end=701,
)


_VECTORSREQUEST = _descriptor.Descriptor(
  name='VectorsRequest',
  full_name='arg_services.nlp.v1.VectorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='arg_services.nlp.v1.VectorsRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='texts', full_name='arg_services.nlp.v1.VectorsRequest.texts', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='embedding_levels', full_name='arg_services.nlp.v1.VectorsRequest.embedding_levels', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=704,
  serialized_end=846,
)


_VECTORSRESPONSE = _descriptor.Descriptor(
  name='VectorsResponse',
  full_name='arg_services.nlp.v1.VectorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vectors', full_name='arg_services.nlp.v1.VectorsResponse.vectors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=848,
  serialized_end=919,
)


_VECTORRESPONSE = _descriptor.Descriptor(
  name='VectorResponse',
  full_name='arg_services.nlp.v1.VectorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document', full_name='arg_services.nlp.v1.VectorResponse.document', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tokens', full_name='arg_services.nlp.v1.VectorResponse.tokens', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sentences', full_name='arg_services.nlp.v1.VectorResponse.sentences', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=922,
  serialized_end=1078,
)


_VECTOR = _descriptor.Descriptor(
  name='Vector',
  full_name='arg_services.nlp.v1.Vector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vector', full_name='arg_services.nlp.v1.Vector.vector', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1080,
  serialized_end=1104,
)


_EMBEDDINGMODEL = _descriptor.Descriptor(
  name='EmbeddingModel',
  full_name='arg_services.nlp.v1.EmbeddingModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_type', full_name='arg_services.nlp.v1.EmbeddingModel.model_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_name', full_name='arg_services.nlp.v1.EmbeddingModel.model_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pooling', full_name='arg_services.nlp.v1.EmbeddingModel.pooling', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1107,
  serialized_end=1246,
)

_NLPCONFIG.fields_by_name['embedding_models'].message_type = _EMBEDDINGMODEL
_NLPCONFIG.fields_by_name['similarity_method'].enum_type = _SIMILARITYMETHOD
_SIMILARITIESREQUEST.fields_by_name['config'].message_type = _NLPCONFIG
_SIMILARITIESREQUEST.fields_by_name['text_tuples'].message_type = _TEXTTUPLE
_DOCBINREQUEST.fields_by_name['config'].message_type = _NLPCONFIG
_DOCBINREQUEST.fields_by_name['embedding_levels'].enum_type = _EMBEDDINGLEVEL
_VECTORSREQUEST.fields_by_name['config'].message_type = _NLPCONFIG
_VECTORSREQUEST.fields_by_name['embedding_levels'].enum_type = _EMBEDDINGLEVEL
_VECTORSRESPONSE.fields_by_name['vectors'].message_type = _VECTORRESPONSE
_VECTORRESPONSE.fields_by_name['document'].message_type = _VECTOR
_VECTORRESPONSE.fields_by_name['tokens'].message_type = _VECTOR
_VECTORRESPONSE.fields_by_name['sentences'].message_type = _VECTOR
_EMBEDDINGMODEL.fields_by_name['model_type'].enum_type = _EMBEDDINGTYPE
_EMBEDDINGMODEL.fields_by_name['pooling'].enum_type = _POOLING
DESCRIPTOR.message_types_by_name['NlpConfig'] = _NLPCONFIG
DESCRIPTOR.message_types_by_name['SimilaritiesRequest'] = _SIMILARITIESREQUEST
DESCRIPTOR.message_types_by_name['SimilaritiesResponse'] = _SIMILARITIESRESPONSE
DESCRIPTOR.message_types_by_name['TextTuple'] = _TEXTTUPLE
DESCRIPTOR.message_types_by_name['DocBinRequest'] = _DOCBINREQUEST
DESCRIPTOR.message_types_by_name['DocBinResponse'] = _DOCBINRESPONSE
DESCRIPTOR.message_types_by_name['VectorsRequest'] = _VECTORSREQUEST
DESCRIPTOR.message_types_by_name['VectorsResponse'] = _VECTORSRESPONSE
DESCRIPTOR.message_types_by_name['VectorResponse'] = _VECTORRESPONSE
DESCRIPTOR.message_types_by_name['Vector'] = _VECTOR
DESCRIPTOR.message_types_by_name['EmbeddingModel'] = _EMBEDDINGMODEL
DESCRIPTOR.enum_types_by_name['SimilarityMethod'] = _SIMILARITYMETHOD
DESCRIPTOR.enum_types_by_name['EmbeddingLevel'] = _EMBEDDINGLEVEL
DESCRIPTOR.enum_types_by_name['Pooling'] = _POOLING
DESCRIPTOR.enum_types_by_name['EmbeddingType'] = _EMBEDDINGTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NlpConfig = _reflection.GeneratedProtocolMessageType('NlpConfig', (_message.Message,), {
  'DESCRIPTOR' : _NLPCONFIG,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.NlpConfig)
  })
_sym_db.RegisterMessage(NlpConfig)

SimilaritiesRequest = _reflection.GeneratedProtocolMessageType('SimilaritiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIMILARITIESREQUEST,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.SimilaritiesRequest)
  })
_sym_db.RegisterMessage(SimilaritiesRequest)

SimilaritiesResponse = _reflection.GeneratedProtocolMessageType('SimilaritiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIMILARITIESRESPONSE,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.SimilaritiesResponse)
  })
_sym_db.RegisterMessage(SimilaritiesResponse)

TextTuple = _reflection.GeneratedProtocolMessageType('TextTuple', (_message.Message,), {
  'DESCRIPTOR' : _TEXTTUPLE,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.TextTuple)
  })
_sym_db.RegisterMessage(TextTuple)

DocBinRequest = _reflection.GeneratedProtocolMessageType('DocBinRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOCBINREQUEST,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.DocBinRequest)
  })
_sym_db.RegisterMessage(DocBinRequest)

DocBinResponse = _reflection.GeneratedProtocolMessageType('DocBinResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOCBINRESPONSE,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.DocBinResponse)
  })
_sym_db.RegisterMessage(DocBinResponse)

VectorsRequest = _reflection.GeneratedProtocolMessageType('VectorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _VECTORSREQUEST,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.VectorsRequest)
  })
_sym_db.RegisterMessage(VectorsRequest)

VectorsResponse = _reflection.GeneratedProtocolMessageType('VectorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _VECTORSRESPONSE,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.VectorsResponse)
  })
_sym_db.RegisterMessage(VectorsResponse)

VectorResponse = _reflection.GeneratedProtocolMessageType('VectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _VECTORRESPONSE,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.VectorResponse)
  })
_sym_db.RegisterMessage(VectorResponse)

Vector = _reflection.GeneratedProtocolMessageType('Vector', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.Vector)
  })
_sym_db.RegisterMessage(Vector)

EmbeddingModel = _reflection.GeneratedProtocolMessageType('EmbeddingModel', (_message.Message,), {
  'DESCRIPTOR' : _EMBEDDINGMODEL,
  '__module__' : 'arg_services.nlp.v1.nlp_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.nlp.v1.EmbeddingModel)
  })
_sym_db.RegisterMessage(EmbeddingModel)


DESCRIPTOR._options = None

_NLPSERVICE = _descriptor.ServiceDescriptor(
  name='NlpService',
  full_name='arg_services.nlp.v1.NlpService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2071,
  serialized_end=2353,
  methods=[
  _descriptor.MethodDescriptor(
    name='DocBin',
    full_name='arg_services.nlp.v1.NlpService.DocBin',
    index=0,
    containing_service=None,
    input_type=_DOCBINREQUEST,
    output_type=_DOCBINRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Vectors',
    full_name='arg_services.nlp.v1.NlpService.Vectors',
    index=1,
    containing_service=None,
    input_type=_VECTORSREQUEST,
    output_type=_VECTORSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Similarities',
    full_name='arg_services.nlp.v1.NlpService.Similarities',
    index=2,
    containing_service=None,
    input_type=_SIMILARITIESREQUEST,
    output_type=_SIMILARITIESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NLPSERVICE)

DESCRIPTOR.services_by_name['NlpService'] = _NLPSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: arg_services/base/v1/base.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='arg_services/base/v1/base.proto',
  package='arg_services.base.v1',
  syntax='proto3',
  serialized_options=b'\n\'de.uni_trier.recap.arg_services.base.v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x61rg_services/base/v1/base.proto\x12\x14\x61rg_services.base.v1B)\n\'de.uni_trier.recap.arg_services.base.v1b\x06proto3'
)



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from arg_services.entailment.v1 import entailment_pb2 as arg__services_dot_entailment_dot_v1_dot_entailment__pb2


class EntailmentServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Entailment = channel.unary_unary(
                '/arg_services.entailment.v1.EntailmentService/Entailment',
                request_serializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentRequest.SerializeToString,
                response_deserializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentResponse.FromString,
                )
        self.Entailments = channel.unary_unary(
                '/arg_services.entailment.v1.EntailmentService/Entailments',
                request_serializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentsRequest.SerializeToString,
                response_deserializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentsResponse.FromString,
                )


class EntailmentServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Entailment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Entailments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EntailmentServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Entailment': grpc.unary_unary_rpc_method_handler(
                    servicer.Entailment,
                    request_deserializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentRequest.FromString,
                    response_serializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentResponse.SerializeToString,
            ),
            'Entailments': grpc.unary_unary_rpc_method_handler(
                    servicer.Entailments,
                    request_deserializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentsRequest.FromString,
                    response_serializer=arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'arg_services.entailment.v1.EntailmentService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EntailmentService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Entailment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/arg_services.entailment.v1.EntailmentService/Entailment',
            arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentRequest.SerializeToString,
            arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Entailments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/arg_services.entailment.v1.EntailmentService/Entailments',
            arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentsRequest.SerializeToString,
            arg__services_dot_entailment_dot_v1_dot_entailment__pb2.EntailmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import arg_services.topic_modeling.v1.topic_modeling_pb2
import grpc

class TopicModelingServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Topics: grpc.UnaryUnaryMultiCallable[
        arg_services.topic_modeling.v1.topic_modeling_pb2.TopicsRequest,
        arg_services.topic_modeling.v1.topic_modeling_pb2.TopicsResponse] = ...


class TopicModelingServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Topics(self,
        request: arg_services.topic_modeling.v1.topic_modeling_pb2.TopicsRequest,
        context: grpc.ServicerContext,
    ) -> arg_services.topic_modeling.v1.topic_modeling_pb2.TopicsResponse: ...


def add_TopicModelingServiceServicer_to_server(servicer: TopicModelingServiceServicer, server: grpc.Server) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from arg_services.nlp.v1 import nlp_pb2 as arg__services_dot_nlp_dot_v1_dot_nlp__pb2


class NlpServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DocBin = channel.unary_unary(
                '/arg_services.nlp.v1.NlpService/DocBin',
                request_serializer=arg__services_dot_nlp_dot_v1_dot_nlp__pb2.DocBinRequest.SerializeToString,
                response_deserializer=arg__services_dot_nlp_dot_v1_dot_nlp__pb2.DocBinResponse.FromString,
                )
        self.Vectors = channel.unary_unary(
                '/arg_services.nlp.v1.NlpService/Vectors',
                request_serializer=arg__services_dot_nlp_dot_v1_dot_nlp__pb2.VectorsRequest.SerializeToString,
                response_deserializer=arg__services_dot_nlp_dot_v1_dot_nlp__pb2.VectorsResponse.FromString,
                )
        self.Similarities = channel.unary_unary(
                '/arg_services.nlp.v1.NlpService/Similarities',
                request_serializer=arg__services_dot_nlp_dot_v1_dot_nlp__pb2.SimilaritiesRequest.SerializeToString,
                response_deserializer=arg__services_dot_nlp_dot_v1_dot_nlp__pb2.SimilaritiesResponse.FromString,
                )


class NlpServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DocBin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Vectors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Similarities(self, request, context):
        """rpc ResetCache (ResetCacheRequest) returns (ResetCacheResponse);
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NlpServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DocBin': grpc.unary_unary_rpc_method_handler(
                    servicer.DocBin,
                    request_deserializer=arg__services_dot_nlp_dot_v1_dot_nlp__pb2.DocBinRequest.FromString,
                    response_serializer=arg__services_dot_nlp_dot_v1_dot_nlp__pb2.DocBinResponse.SerializeToString,
            ),
            'Vectors': grpc.unary_unary_rpc_method_handler(
                    servicer.Vectors,
                    request_deserializer=arg__services_dot_nlp_dot_v1_dot_nlp__pb2.VectorsRequest.FromString,
                    response_serializer=arg__services_dot_nlp_dot_v1_dot_nlp__pb2.VectorsResponse.SerializeToString,
            ),
            'Similarities': grpc.unary_unary_rpc_method_handler(
                    servicer.Similarities,
                    request_deserializer=arg__services_dot_nlp_dot_v1_dot_nlp__pb2.SimilaritiesRequest.FromString,
                    response_serializer=arg__services_dot_nlp_dot_v1_dot_nlp__pb2.SimilaritiesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'arg_services.nlp.v1.NlpService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NlpService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DocBin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/arg_services.nlp.v1.NlpService/DocBin',
            arg__services_dot_nlp_dot_v1_dot_nlp__pb2.DocBinRequest.SerializeToString,
            arg__services_dot_nlp_dot_v1_dot_nlp__pb2.DocBinResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Vectors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/arg_services.nlp.v1.NlpService/Vectors',
            arg__services_dot_nlp_dot_v1_dot_nlp__pb2.VectorsRequest.SerializeToString,
            arg__services_dot_nlp_dot_v1_dot_nlp__pb2.VectorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Similarities(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/arg_services.nlp.v1.NlpService/Similarities',
            arg__services_dot_nlp_dot_v1_dot_nlp__pb2.SimilaritiesRequest.SerializeToString,
            arg__services_dot_nlp_dot_v1_dot_nlp__pb2.SimilaritiesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Scheme(_Scheme, metaclass=_SchemeEnumTypeWrapper):
    pass
class _Scheme:
    V = typing.NewType('V', builtins.int)
class _SchemeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Scheme.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    SCHEME_UNSPECIFIED = Scheme.V(0)
    SCHEME_AD_HOMINEM = Scheme.V(1)
    SCHEME_ALTERNATIVE_MEANS = Scheme.V(2)
    SCHEME_ALTERNATIVES = Scheme.V(3)
    SCHEME_ANALOGY = Scheme.V(4)
    SCHEME_ARBITRARY_VERBAL_CLASSIFICATION = Scheme.V(5)
    SCHEME_AUTHORITY = Scheme.V(6)
    SCHEME_BIAS = Scheme.V(7)
    SCHEME_BIASED_CLASSIFICATION = Scheme.V(8)
    SCHEME_CALLING_OUT = Scheme.V(9)
    SCHEME_CAUSAL_SLIPPERY_SLOPE = Scheme.V(10)
    SCHEME_CAUSE_TO_EFFECT = Scheme.V(11)
    SCHEME_CIRCUMSTANTIAL_AD_HOMINEM = Scheme.V(12)
    SCHEME_COMMITMENT_EXCEPTION = Scheme.V(13)
    SCHEME_COMMITMENT = Scheme.V(14)
    SCHEME_COMPOSITION = Scheme.V(15)
    SCHEME_CONFLICTING_GOALS = Scheme.V(16)
    SCHEME_CONSEQUENCES = Scheme.V(17)
    SCHEME_CORRELATION_TO_CAUSE = Scheme.V(18)
    SCHEME_DANGER_APPEAL = Scheme.V(19)
    SCHEME_DEFINITION_TO_VERBAL_CLASSIFICATION = Scheme.V(20)
    SCHEME_DIFFERENCES_UNDERMINE_SIMILARITY = Scheme.V(21)
    SCHEME_DILEMMA = Scheme.V(22)
    SCHEME_DIRECT_AD_HOMINEM = Scheme.V(23)
    SCHEME_DIVISION = Scheme.V(24)
    SCHEME_ESTABLISHED_RULE = Scheme.V(25)
    SCHEME_ETHOTIC = Scheme.V(26)
    SCHEME_EVIDENCE_TO_HYPOTHESIS = Scheme.V(27)
    SCHEME_EXAMPLE = Scheme.V(28)
    SCHEME_EXCEPTION_SIMILARITY_CASE = Scheme.V(29)
    SCHEME_EXCEPTIONAL_CASE = Scheme.V(30)
    SCHEME_EXPERT_OPINION = Scheme.V(31)
    SCHEME_EXPERTISE_INCONSISTENCY = Scheme.V(32)
    SCHEME_FAIRNESS = Scheme.V(33)
    SCHEME_FALSIFICATION_OF_HYPOTHESIS = Scheme.V(34)
    SCHEME_FEAR_APPEAL = Scheme.V(35)
    SCHEME_FULL_SLIPPERY_SLOPE = Scheme.V(36)
    SCHEME_GENERAL_ACCEPTANCE_DOUBT = Scheme.V(37)
    SCHEME_GENERIC_AD_HOMINEM = Scheme.V(38)
    SCHEME_GOODWILL = Scheme.V(39)
    SCHEME_GRADUALISM = Scheme.V(40)
    SCHEME_IGNORANCE = Scheme.V(41)
    SCHEME_INCONSISTENT_COMMITMENT = Scheme.V(42)
    SCHEME_INFORMANT_REPORT = Scheme.V(43)
    SCHEME_INTERACTION_OF_ACT_AND_PERSON = Scheme.V(44)
    SCHEME_IRRATIONAL_FEAR_APPEAL = Scheme.V(45)
    SCHEME_LACK_OF_COMPLETE_KNOWLEDGE = Scheme.V(46)
    SCHEME_LACK_OF_EXPERT_RELIABILITY = Scheme.V(47)
    SCHEME_LOGICAL = Scheme.V(48)
    SCHEME_MISPLACED_PRIORITIES = Scheme.V(49)
    SCHEME_MODUS_PONENS = Scheme.V(50)
    SCHEME_MORAL_VIRTUE = Scheme.V(51)
    SCHEME_NEED_FOR_HELP = Scheme.V(52)
    SCHEME_NEGATIVE_CONSEQUENCES = Scheme.V(53)
    SCHEME_OPPOSED_COMMITMENT = Scheme.V(54)
    SCHEME_OPPOSITIONS = Scheme.V(55)
    SCHEME_CAUSAL_FACTORS_INVOLVED = Scheme.V(56)
    SCHEME_PARAPHRASE = Scheme.V(57)
    SCHEME_PERCEPTION = Scheme.V(58)
    SCHEME_POPULAR_OPINION = Scheme.V(59)
    SCHEME_POPULAR_PRACTICE = Scheme.V(60)
    SCHEME_POSITION_TO_KNOW = Scheme.V(61)
    SCHEME_POSITIVE_CONSEQUENCES = Scheme.V(62)
    SCHEME_PRACTICAL_REASONING_FROM_ANALOGY = Scheme.V(63)
    SCHEME_PRACTICAL_REASONING = Scheme.V(64)
    SCHEME_PRACTICAL_WISDOM = Scheme.V(65)
    SCHEME_PRAGMATIC_ALTERNATIVES = Scheme.V(66)
    SCHEME_PRAGMATIC_INCONSISTENCY = Scheme.V(67)
    SCHEME_PRECEDENT_SLIPPERY_SLOPE = Scheme.V(68)
    SCHEME_PROPERTY_NOT_EXISTANT = Scheme.V(69)
    SCHEME_REFRAMING = Scheme.V(70)
    SCHEME_REQUIRED_STEPS = Scheme.V(71)
    SCHEME_RESOLVING_INCONSISTENCY = Scheme.V(72)
    SCHEME_RULE = Scheme.V(73)
    SCHEME_RULES = Scheme.V(74)
    SCHEME_SIGN_FROM_OTHER_EVENTS = Scheme.V(75)
    SCHEME_SIGN = Scheme.V(76)
    SCHEME_TWO_PERSON_PRACTICAL_REASONING = Scheme.V(77)
    SCHEME_UNFAIRNESS = Scheme.V(78)
    SCHEME_VAGUE_VERBAL_CLASSIFICATION = Scheme.V(79)
    SCHEME_VAGUENESS_OF_VERBAL_CLASSIFICATION = Scheme.V(80)
    SCHEME_VALUE_BASED_PRACTICAL_REASONING = Scheme.V(81)
    SCHEME_VALUES = Scheme.V(82)
    SCHEME_VERBAL_CLASSIFICATION = Scheme.V(83)
    SCHEME_VERBAL_SLIPPERY_SLOPE = Scheme.V(84)
    SCHEME_VESTED_INTEREST = Scheme.V(85)
    SCHEME_VIRTUE_GOODWILL = Scheme.V(86)
    SCHEME_WASTE = Scheme.V(87)
    SCHEME_WEAKEST_LINK = Scheme.V(88)
    SCHEME_WISDOM_GOODWILL = Scheme.V(89)
    SCHEME_WISDOM_VIRTUE = Scheme.V(90)
    SCHEME_WISDOM_VIRTUE_GOODWILL = Scheme.V(91)
    SCHEME_WITNESS_TESTIMONY = Scheme.V(92)

SCHEME_UNSPECIFIED = Scheme.V(0)
SCHEME_AD_HOMINEM = Scheme.V(1)
SCHEME_ALTERNATIVE_MEANS = Scheme.V(2)
SCHEME_ALTERNATIVES = Scheme.V(3)
SCHEME_ANALOGY = Scheme.V(4)
SCHEME_ARBITRARY_VERBAL_CLASSIFICATION = Scheme.V(5)
SCHEME_AUTHORITY = Scheme.V(6)
SCHEME_BIAS = Scheme.V(7)
SCHEME_BIASED_CLASSIFICATION = Scheme.V(8)
SCHEME_CALLING_OUT = Scheme.V(9)
SCHEME_CAUSAL_SLIPPERY_SLOPE = Scheme.V(10)
SCHEME_CAUSE_TO_EFFECT = Scheme.V(11)
SCHEME_CIRCUMSTANTIAL_AD_HOMINEM = Scheme.V(12)
SCHEME_COMMITMENT_EXCEPTION = Scheme.V(13)
SCHEME_COMMITMENT = Scheme.V(14)
SCHEME_COMPOSITION = Scheme.V(15)
SCHEME_CONFLICTING_GOALS = Scheme.V(16)
SCHEME_CONSEQUENCES = Scheme.V(17)
SCHEME_CORRELATION_TO_CAUSE = Scheme.V(18)
SCHEME_DANGER_APPEAL = Scheme.V(19)
SCHEME_DEFINITION_TO_VERBAL_CLASSIFICATION = Scheme.V(20)
SCHEME_DIFFERENCES_UNDERMINE_SIMILARITY = Scheme.V(21)
SCHEME_DILEMMA = Scheme.V(22)
SCHEME_DIRECT_AD_HOMINEM = Scheme.V(23)
SCHEME_DIVISION = Scheme.V(24)
SCHEME_ESTABLISHED_RULE = Scheme.V(25)
SCHEME_ETHOTIC = Scheme.V(26)
SCHEME_EVIDENCE_TO_HYPOTHESIS = Scheme.V(27)
SCHEME_EXAMPLE = Scheme.V(28)
SCHEME_EXCEPTION_SIMILARITY_CASE = Scheme.V(29)
SCHEME_EXCEPTIONAL_CASE = Scheme.V(30)
SCHEME_EXPERT_OPINION = Scheme.V(31)
SCHEME_EXPERTISE_INCONSISTENCY = Scheme.V(32)
SCHEME_FAIRNESS = Scheme.V(33)
SCHEME_FALSIFICATION_OF_HYPOTHESIS = Scheme.V(34)
SCHEME_FEAR_APPEAL = Scheme.V(35)
SCHEME_FULL_SLIPPERY_SLOPE = Scheme.V(36)
SCHEME_GENERAL_ACCEPTANCE_DOUBT = Scheme.V(37)
SCHEME_GENERIC_AD_HOMINEM = Scheme.V(38)
SCHEME_GOODWILL = Scheme.V(39)
SCHEME_GRADUALISM = Scheme.V(40)
SCHEME_IGNORANCE = Scheme.V(41)
SCHEME_INCONSISTENT_COMMITMENT = Scheme.V(42)
SCHEME_INFORMANT_REPORT = Scheme.V(43)
SCHEME_INTERACTION_OF_ACT_AND_PERSON = Scheme.V(44)
SCHEME_IRRATIONAL_FEAR_APPEAL = Scheme.V(45)
SCHEME_LACK_OF_COMPLETE_KNOWLEDGE = Scheme.V(46)
SCHEME_LACK_OF_EXPERT_RELIABILITY = Scheme.V(47)
SCHEME_LOGICAL = Scheme.V(48)
SCHEME_MISPLACED_PRIORITIES = Scheme.V(49)
SCHEME_MODUS_PONENS = Scheme.V(50)
SCHEME_MORAL_VIRTUE = Scheme.V(51)
SCHEME_NEED_FOR_HELP = Scheme.V(52)
SCHEME_NEGATIVE_CONSEQUENCES = Scheme.V(53)
SCHEME_OPPOSED_COMMITMENT = Scheme.V(54)
SCHEME_OPPOSITIONS = Scheme.V(55)
SCHEME_CAUSAL_FACTORS_INVOLVED = Scheme.V(56)
SCHEME_PARAPHRASE = Scheme.V(57)
SCHEME_PERCEPTION = Scheme.V(58)
SCHEME_POPULAR_OPINION = Scheme.V(59)
SCHEME_POPULAR_PRACTICE = Scheme.V(60)
SCHEME_POSITION_TO_KNOW = Scheme.V(61)
SCHEME_POSITIVE_CONSEQUENCES = Scheme.V(62)
SCHEME_PRACTICAL_REASONING_FROM_ANALOGY = Scheme.V(63)
SCHEME_PRACTICAL_REASONING = Scheme.V(64)
SCHEME_PRACTICAL_WISDOM = Scheme.V(65)
SCHEME_PRAGMATIC_ALTERNATIVES = Scheme.V(66)
SCHEME_PRAGMATIC_INCONSISTENCY = Scheme.V(67)
SCHEME_PRECEDENT_SLIPPERY_SLOPE = Scheme.V(68)
SCHEME_PROPERTY_NOT_EXISTANT = Scheme.V(69)
SCHEME_REFRAMING = Scheme.V(70)
SCHEME_REQUIRED_STEPS = Scheme.V(71)
SCHEME_RESOLVING_INCONSISTENCY = Scheme.V(72)
SCHEME_RULE = Scheme.V(73)
SCHEME_RULES = Scheme.V(74)
SCHEME_SIGN_FROM_OTHER_EVENTS = Scheme.V(75)
SCHEME_SIGN = Scheme.V(76)
SCHEME_TWO_PERSON_PRACTICAL_REASONING = Scheme.V(77)
SCHEME_UNFAIRNESS = Scheme.V(78)
SCHEME_VAGUE_VERBAL_CLASSIFICATION = Scheme.V(79)
SCHEME_VAGUENESS_OF_VERBAL_CLASSIFICATION = Scheme.V(80)
SCHEME_VALUE_BASED_PRACTICAL_REASONING = Scheme.V(81)
SCHEME_VALUES = Scheme.V(82)
SCHEME_VERBAL_CLASSIFICATION = Scheme.V(83)
SCHEME_VERBAL_SLIPPERY_SLOPE = Scheme.V(84)
SCHEME_VESTED_INTEREST = Scheme.V(85)
SCHEME_VIRTUE_GOODWILL = Scheme.V(86)
SCHEME_WASTE = Scheme.V(87)
SCHEME_WEAKEST_LINK = Scheme.V(88)
SCHEME_WISDOM_GOODWILL = Scheme.V(89)
SCHEME_WISDOM_VIRTUE = Scheme.V(90)
SCHEME_WISDOM_VIRTUE_GOODWILL = Scheme.V(91)
SCHEME_WITNESS_TESTIMONY = Scheme.V(92)
global___Scheme = Scheme


class SchemeType(_SchemeType, metaclass=_SchemeTypeEnumTypeWrapper):
    pass
class _SchemeType:
    V = typing.NewType('V', builtins.int)
class _SchemeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SchemeType.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    SCHEME_TYPE_UNSPECIFIED = SchemeType.V(0)
    SCHEME_TYPE_SUPPORT = SchemeType.V(1)
    SCHEME_TYPE_ATTACK = SchemeType.V(2)
    SCHEME_TYPE_REPHRASE = SchemeType.V(3)
    SCHEME_TYPE_TRANSITION = SchemeType.V(4)
    SCHEME_TYPE_PREFERENCE = SchemeType.V(5)
    SCHEME_TYPE_ASSERTION = SchemeType.V(6)

SCHEME_TYPE_UNSPECIFIED = SchemeType.V(0)
SCHEME_TYPE_SUPPORT = SchemeType.V(1)
SCHEME_TYPE_ATTACK = SchemeType.V(2)
SCHEME_TYPE_REPHRASE = SchemeType.V(3)
SCHEME_TYPE_TRANSITION = SchemeType.V(4)
SCHEME_TYPE_PREFERENCE = SchemeType.V(5)
SCHEME_TYPE_ASSERTION = SchemeType.V(6)
global___SchemeType = SchemeType


class Graph(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class NodesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text = ...
        @property
        def value(self) -> global___Node: ...
        def __init__(self,
            *,
            key : typing.Text = ...,
            value : typing.Optional[global___Node] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...

    class EdgesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text = ...
        @property
        def value(self) -> global___Edge: ...
        def __init__(self,
            *,
            key : typing.Text = ...,
            value : typing.Optional[global___Edge] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...

    class ResourcesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text = ...
        @property
        def value(self) -> global___Resource: ...
        def __init__(self,
            *,
            key : typing.Text = ...,
            value : typing.Optional[global___Resource] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...

    class ParticipantsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text = ...
        @property
        def value(self) -> global___Participant: ...
        def __init__(self,
            *,
            key : typing.Text = ...,
            value : typing.Optional[global___Participant] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...

    NODES_FIELD_NUMBER: builtins.int
    EDGES_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    PARTICIPANTS_FIELD_NUMBER: builtins.int
    MAJOR_CLAIM_FIELD_NUMBER: builtins.int
    ANALYSTS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    UPDATED_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def nodes(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___Node]:
        """string id = 1;"""
        pass
    @property
    def edges(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___Edge]: ...
    @property
    def resources(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___Resource]: ...
    @property
    def participants(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___Participant]: ...
    major_claim: typing.Text = ...
    @property
    def analysts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Participant]: ...
    version: typing.Text = ...
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def metadata(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(self,
        *,
        nodes : typing.Optional[typing.Mapping[typing.Text, global___Node]] = ...,
        edges : typing.Optional[typing.Mapping[typing.Text, global___Edge]] = ...,
        resources : typing.Optional[typing.Mapping[typing.Text, global___Resource]] = ...,
        participants : typing.Optional[typing.Mapping[typing.Text, global___Participant]] = ...,
        major_claim : typing.Text = ...,
        analysts : typing.Optional[typing.Iterable[global___Participant]] = ...,
        version : typing.Text = ...,
        created : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        updated : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        metadata : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"created",b"created",u"metadata",b"metadata",u"updated",b"updated"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"analysts",b"analysts",u"created",b"created",u"edges",b"edges",u"major_claim",b"major_claim",u"metadata",b"metadata",u"nodes",b"nodes",u"participants",b"participants",u"resources",b"resources",u"updated",b"updated",u"version",b"version"]) -> None: ...
global___Graph = Graph

class Resource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    UPDATED_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    """string id = 1;"""

    title: typing.Text = ...
    source: typing.Text = ...
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def metadata(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(self,
        *,
        text : typing.Text = ...,
        title : typing.Text = ...,
        source : typing.Text = ...,
        created : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        updated : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        metadata : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"created",b"created",u"metadata",b"metadata",u"updated",b"updated"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"created",b"created",u"metadata",b"metadata",u"source",b"source",u"text",b"text",u"title",b"title",u"updated",b"updated"]) -> None: ...
global___Resource = Resource

class Participant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    UPDATED_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    name: typing.Text = ...
    """string id = 1;"""

    username: typing.Text = ...
    email: typing.Text = ...
    url: typing.Text = ...
    location: typing.Text = ...
    description: typing.Text = ...
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def metadata(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(self,
        *,
        name : typing.Text = ...,
        username : typing.Text = ...,
        email : typing.Text = ...,
        url : typing.Text = ...,
        location : typing.Text = ...,
        description : typing.Text = ...,
        created : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        updated : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        metadata : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"created",b"created",u"metadata",b"metadata",u"updated",b"updated"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"created",b"created",u"description",b"description",u"email",b"email",u"location",b"location",u"metadata",b"metadata",u"name",b"name",u"updated",b"updated",u"url",b"url",u"username",b"username"]) -> None: ...
global___Participant = Participant

class Edge(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SOURCE_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    UPDATED_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    source: typing.Text = ...
    """string id = 1;"""

    target: typing.Text = ...
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def metadata(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(self,
        *,
        source : typing.Text = ...,
        target : typing.Text = ...,
        created : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        updated : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        metadata : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"created",b"created",u"metadata",b"metadata",u"updated",b"updated"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"created",b"created",u"metadata",b"metadata",u"source",b"source",u"target",b"target",u"updated",b"updated"]) -> None: ...
global___Edge = Edge

class Node(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ATOM_FIELD_NUMBER: builtins.int
    SCHEME_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    UPDATED_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def atom(self) -> global___AtomNode: ...
    @property
    def scheme(self) -> global___SchemeNode: ...
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def metadata(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(self,
        *,
        atom : typing.Optional[global___AtomNode] = ...,
        scheme : typing.Optional[global___SchemeNode] = ...,
        created : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        updated : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        metadata : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"atom",b"atom",u"created",b"created",u"metadata",b"metadata",u"node",b"node",u"scheme",b"scheme",u"updated",b"updated"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"atom",b"atom",u"created",b"created",u"metadata",b"metadata",u"node",b"node",u"scheme",b"scheme",u"updated",b"updated"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"node",b"node"]) -> typing.Optional[typing_extensions.Literal["atom","scheme"]]: ...
global___Node = Node

class AtomNode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    REFERENCE_FIELD_NUMBER: builtins.int
    PARTICIPANT_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    @property
    def reference(self) -> global___Reference: ...
    participant: typing.Text = ...
    def __init__(self,
        *,
        text : typing.Text = ...,
        reference : typing.Optional[global___Reference] = ...,
        participant : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"reference",b"reference"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"participant",b"participant",u"reference",b"reference",u"text",b"text"]) -> None: ...
global___AtomNode = AtomNode

class SchemeNode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    ARGUMENTATION_SCHEME_FIELD_NUMBER: builtins.int
    DESCRIPTORS_FIELD_NUMBER: builtins.int
    type: global___SchemeType.V = ...
    argumentation_scheme: global___Scheme.V = ...
    @property
    def descriptors(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(self,
        *,
        type : global___SchemeType.V = ...,
        argumentation_scheme : global___Scheme.V = ...,
        descriptors : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"descriptors",b"descriptors"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"argumentation_scheme",b"argumentation_scheme",u"descriptors",b"descriptors",u"type",b"type"]) -> None: ...
global___SchemeNode = SchemeNode

class Reference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    resource: typing.Text = ...
    """string id = 1;"""

    offset: builtins.int = ...
    text: typing.Text = ...
    @property
    def metadata(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(self,
        *,
        resource : typing.Text = ...,
        offset : builtins.int = ...,
        text : typing.Text = ...,
        metadata : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"metadata",b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"metadata",b"metadata",u"offset",b"offset",u"resource",b"resource",u"text",b"text"]) -> None: ...
global___Reference = Reference



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import arg_services.entailment.v1.entailment_pb2
import grpc

class EntailmentServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Entailment: grpc.UnaryUnaryMultiCallable[
        arg_services.entailment.v1.entailment_pb2.EntailmentRequest,
        arg_services.entailment.v1.entailment_pb2.EntailmentResponse] = ...

    Entailments: grpc.UnaryUnaryMultiCallable[
        arg_services.entailment.v1.entailment_pb2.EntailmentsRequest,
        arg_services.entailment.v1.entailment_pb2.EntailmentsResponse] = ...


class EntailmentServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Entailment(self,
        request: arg_services.entailment.v1.entailment_pb2.EntailmentRequest,
        context: grpc.ServicerContext,
    ) -> arg_services.entailment.v1.entailment_pb2.EntailmentResponse: ...

    @abc.abstractmethod
    def Entailments(self,
        request: arg_services.entailment.v1.entailment_pb2.EntailmentsRequest,
        context: grpc.ServicerContext,
    ) -> arg_services.entailment.v1.entailment_pb2.EntailmentsResponse: ...


def add_EntailmentServiceServicer_to_server(servicer: EntailmentServiceServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: arg_services/adu/v1/adu.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='arg_services/adu/v1/adu.proto',
  package='arg_services.adu.v1',
  syntax='proto3',
  serialized_options=b'\n&de.uni_trier.recap.arg_services.adu.v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x61rg_services/adu/v1/adu.proto\x12\x13\x61rg_services.adu.v1\"Z\n\x13SegmentationRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x35\n\x0bgranularity\x18\x02 \x01(\x0e\x32 .arg_services.adu.v1.Granularity\"(\n\x14SegmentationResponse\x12\x10\n\x08segments\x18\x01 \x03(\t\"^\n\x15\x43lassificationRequest\x12\x10\n\x08segments\x18\x01 \x03(\t\x12\x33\n\nclassifier\x18\x02 \x01(\x0e\x32\x1f.arg_services.adu.v1.Classifier\"R\n\x16\x43lassificationResponse\x12\x38\n\x08segments\x18\x01 \x03(\x0b\x32&.arg_services.adu.v1.ClassifiedSegment\"N\n\x11\x43lassifiedSegment\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03\x61\x64u\x18\x02 \x01(\x08\x12\r\n\x05\x63laim\x18\x03 \x01(\x08\x12\x0f\n\x07premise\x18\x04 \x01(\x08*|\n\x0bGranularity\x12\x1b\n\x17GRANULARITY_UNSPECIFIED\x10\x00\x12\x18\n\x14GRANULARITY_SENTENCE\x10\x01\x12\x1b\n\x17GRANULARITY_SUBSENTENCE\x10\x02\x12\x19\n\x15GRANULARITY_PARAGRAPH\x10\x03*u\n\nClassifier\x12\x1a\n\x16\x43LASSIFIER_UNSPECIFIED\x10\x00\x12\x16\n\x12\x43LASSIFIER_TWO_WAY\x10\x01\x12\x18\n\x14\x43LASSIFIER_THREE_WAY\x10\x02\x12\x19\n\x15\x43LASSIFIER_SEQUENTIAL\x10\x03\x32\xdc\x01\n\nAduService\x12\x63\n\x0cSegmentation\x12(.arg_services.adu.v1.SegmentationRequest\x1a).arg_services.adu.v1.SegmentationResponse\x12i\n\x0e\x43lassification\x12*.arg_services.adu.v1.ClassificationRequest\x1a+.arg_services.adu.v1.ClassificationResponseB(\n&de.uni_trier.recap.arg_services.adu.v1b\x06proto3'
)

_GRANULARITY = _descriptor.EnumDescriptor(
  name='Granularity',
  full_name='arg_services.adu.v1.Granularity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GRANULARITY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRANULARITY_SENTENCE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRANULARITY_SUBSENTENCE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRANULARITY_PARAGRAPH', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=448,
  serialized_end=572,
)
_sym_db.RegisterEnumDescriptor(_GRANULARITY)

Granularity = enum_type_wrapper.EnumTypeWrapper(_GRANULARITY)
_CLASSIFIER = _descriptor.EnumDescriptor(
  name='Classifier',
  full_name='arg_services.adu.v1.Classifier',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLASSIFIER_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLASSIFIER_TWO_WAY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLASSIFIER_THREE_WAY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLASSIFIER_SEQUENTIAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=574,
  serialized_end=691,
)
_sym_db.RegisterEnumDescriptor(_CLASSIFIER)

Classifier = enum_type_wrapper.EnumTypeWrapper(_CLASSIFIER)
GRANULARITY_UNSPECIFIED = 0
GRANULARITY_SENTENCE = 1
GRANULARITY_SUBSENTENCE = 2
GRANULARITY_PARAGRAPH = 3
CLASSIFIER_UNSPECIFIED = 0
CLASSIFIER_TWO_WAY = 1
CLASSIFIER_THREE_WAY = 2
CLASSIFIER_SEQUENTIAL = 3



_SEGMENTATIONREQUEST = _descriptor.Descriptor(
  name='SegmentationRequest',
  full_name='arg_services.adu.v1.SegmentationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='arg_services.adu.v1.SegmentationRequest.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='granularity', full_name='arg_services.adu.v1.SegmentationRequest.granularity', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=144,
)


_SEGMENTATIONRESPONSE = _descriptor.Descriptor(
  name='SegmentationResponse',
  full_name='arg_services.adu.v1.SegmentationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segments', full_name='arg_services.adu.v1.SegmentationResponse.segments', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=186,
)


_CLASSIFICATIONREQUEST = _descriptor.Descriptor(
  name='ClassificationRequest',
  full_name='arg_services.adu.v1.ClassificationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segments', full_name='arg_services.adu.v1.ClassificationRequest.segments', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classifier', full_name='arg_services.adu.v1.ClassificationRequest.classifier', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=282,
)


_CLASSIFICATIONRESPONSE = _descriptor.Descriptor(
  name='ClassificationResponse',
  full_name='arg_services.adu.v1.ClassificationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segments', full_name='arg_services.adu.v1.ClassificationResponse.segments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=366,
)


_CLASSIFIEDSEGMENT = _descriptor.Descriptor(
  name='ClassifiedSegment',
  full_name='arg_services.adu.v1.ClassifiedSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='arg_services.adu.v1.ClassifiedSegment.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adu', full_name='arg_services.adu.v1.ClassifiedSegment.adu', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claim', full_name='arg_services.adu.v1.ClassifiedSegment.claim', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='premise', full_name='arg_services.adu.v1.ClassifiedSegment.premise', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=446,
)

_SEGMENTATIONREQUEST.fields_by_name['granularity'].enum_type = _GRANULARITY
_CLASSIFICATIONREQUEST.fields_by_name['classifier'].enum_type = _CLASSIFIER
_CLASSIFICATIONRESPONSE.fields_by_name['segments'].message_type = _CLASSIFIEDSEGMENT
DESCRIPTOR.message_types_by_name['SegmentationRequest'] = _SEGMENTATIONREQUEST
DESCRIPTOR.message_types_by_name['SegmentationResponse'] = _SEGMENTATIONRESPONSE
DESCRIPTOR.message_types_by_name['ClassificationRequest'] = _CLASSIFICATIONREQUEST
DESCRIPTOR.message_types_by_name['ClassificationResponse'] = _CLASSIFICATIONRESPONSE
DESCRIPTOR.message_types_by_name['ClassifiedSegment'] = _CLASSIFIEDSEGMENT
DESCRIPTOR.enum_types_by_name['Granularity'] = _GRANULARITY
DESCRIPTOR.enum_types_by_name['Classifier'] = _CLASSIFIER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SegmentationRequest = _reflection.GeneratedProtocolMessageType('SegmentationRequest', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTATIONREQUEST,
  '__module__' : 'arg_services.adu.v1.adu_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.adu.v1.SegmentationRequest)
  })
_sym_db.RegisterMessage(SegmentationRequest)

SegmentationResponse = _reflection.GeneratedProtocolMessageType('SegmentationResponse', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTATIONRESPONSE,
  '__module__' : 'arg_services.adu.v1.adu_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.adu.v1.SegmentationResponse)
  })
_sym_db.RegisterMessage(SegmentationResponse)

ClassificationRequest = _reflection.GeneratedProtocolMessageType('ClassificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLASSIFICATIONREQUEST,
  '__module__' : 'arg_services.adu.v1.adu_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.adu.v1.ClassificationRequest)
  })
_sym_db.RegisterMessage(ClassificationRequest)

ClassificationResponse = _reflection.GeneratedProtocolMessageType('ClassificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLASSIFICATIONRESPONSE,
  '__module__' : 'arg_services.adu.v1.adu_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.adu.v1.ClassificationResponse)
  })
_sym_db.RegisterMessage(ClassificationResponse)

ClassifiedSegment = _reflection.GeneratedProtocolMessageType('ClassifiedSegment', (_message.Message,), {
  'DESCRIPTOR' : _CLASSIFIEDSEGMENT,
  '__module__' : 'arg_services.adu.v1.adu_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.adu.v1.ClassifiedSegment)
  })
_sym_db.RegisterMessage(ClassifiedSegment)


DESCRIPTOR._options = None

_ADUSERVICE = _descriptor.ServiceDescriptor(
  name='AduService',
  full_name='arg_services.adu.v1.AduService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=694,
  serialized_end=914,
  methods=[
  _descriptor.MethodDescriptor(
    name='Segmentation',
    full_name='arg_services.adu.v1.AduService.Segmentation',
    index=0,
    containing_service=None,
    input_type=_SEGMENTATIONREQUEST,
    output_type=_SEGMENTATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Classification',
    full_name='arg_services.adu.v1.AduService.Classification',
    index=1,
    containing_service=None,
    input_type=_CLASSIFICATIONREQUEST,
    output_type=_CLASSIFICATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADUSERVICE)

DESCRIPTOR.services_by_name['AduService'] = _ADUSERVICE

# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SimilarityMethod(_SimilarityMethod, metaclass=_SimilarityMethodEnumTypeWrapper):
    pass
class _SimilarityMethod:
    V = typing.NewType('V', builtins.int)
class _SimilarityMethodEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SimilarityMethod.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    SIMILARITY_METHOD_UNSPECIFIED = SimilarityMethod.V(0)
    SIMILARITY_METHOD_COSINE = SimilarityMethod.V(1)
    SIMILARITY_METHOD_DYNAMAX_JACCARD = SimilarityMethod.V(2)
    SIMILARITY_METHOD_MAXPOOL_JACCARD = SimilarityMethod.V(3)
    SIMILARITY_METHOD_DYNAMAX_DICE = SimilarityMethod.V(4)
    SIMILARITY_METHOD_DYNAMAX_OTSUKA = SimilarityMethod.V(5)
    SIMILARITY_METHOD_WMD = SimilarityMethod.V(6)
    SIMILARITY_METHOD_EDIT = SimilarityMethod.V(7)
    SIMILARITY_METHOD_JACCARD = SimilarityMethod.V(8)
    SIMILARITY_METHOD_ANGULAR = SimilarityMethod.V(9)

SIMILARITY_METHOD_UNSPECIFIED = SimilarityMethod.V(0)
SIMILARITY_METHOD_COSINE = SimilarityMethod.V(1)
SIMILARITY_METHOD_DYNAMAX_JACCARD = SimilarityMethod.V(2)
SIMILARITY_METHOD_MAXPOOL_JACCARD = SimilarityMethod.V(3)
SIMILARITY_METHOD_DYNAMAX_DICE = SimilarityMethod.V(4)
SIMILARITY_METHOD_DYNAMAX_OTSUKA = SimilarityMethod.V(5)
SIMILARITY_METHOD_WMD = SimilarityMethod.V(6)
SIMILARITY_METHOD_EDIT = SimilarityMethod.V(7)
SIMILARITY_METHOD_JACCARD = SimilarityMethod.V(8)
SIMILARITY_METHOD_ANGULAR = SimilarityMethod.V(9)
global___SimilarityMethod = SimilarityMethod


class EmbeddingLevel(_EmbeddingLevel, metaclass=_EmbeddingLevelEnumTypeWrapper):
    pass
class _EmbeddingLevel:
    V = typing.NewType('V', builtins.int)
class _EmbeddingLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EmbeddingLevel.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    EMBEDDING_LEVEL_UNSPECIFIED = EmbeddingLevel.V(0)
    EMBEDDING_LEVEL_DOCUMENT = EmbeddingLevel.V(1)
    EMBEDDING_LEVEL_TOKENS = EmbeddingLevel.V(2)
    EMBEDDING_LEVEL_SENTENCES = EmbeddingLevel.V(3)

EMBEDDING_LEVEL_UNSPECIFIED = EmbeddingLevel.V(0)
EMBEDDING_LEVEL_DOCUMENT = EmbeddingLevel.V(1)
EMBEDDING_LEVEL_TOKENS = EmbeddingLevel.V(2)
EMBEDDING_LEVEL_SENTENCES = EmbeddingLevel.V(3)
global___EmbeddingLevel = EmbeddingLevel


class Pooling(_Pooling, metaclass=_PoolingEnumTypeWrapper):
    pass
class _Pooling:
    V = typing.NewType('V', builtins.int)
class _PoolingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Pooling.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    POOLING_UNSPECIFIED = Pooling.V(0)
    POOLING_MEAN = Pooling.V(1)
    POOLING_MAX = Pooling.V(2)
    POOLING_MIN = Pooling.V(3)
    POOLING_SUM = Pooling.V(4)
    POOLING_FIRST = Pooling.V(5)
    POOLING_LAST = Pooling.V(6)
    POOLING_MEDIAN = Pooling.V(7)
    POOLING_GMEAN = Pooling.V(8)
    POOLING_HMEAN = Pooling.V(9)

POOLING_UNSPECIFIED = Pooling.V(0)
POOLING_MEAN = Pooling.V(1)
POOLING_MAX = Pooling.V(2)
POOLING_MIN = Pooling.V(3)
POOLING_SUM = Pooling.V(4)
POOLING_FIRST = Pooling.V(5)
POOLING_LAST = Pooling.V(6)
POOLING_MEDIAN = Pooling.V(7)
POOLING_GMEAN = Pooling.V(8)
POOLING_HMEAN = Pooling.V(9)
global___Pooling = Pooling


class EmbeddingType(_EmbeddingType, metaclass=_EmbeddingTypeEnumTypeWrapper):
    pass
class _EmbeddingType:
    V = typing.NewType('V', builtins.int)
class _EmbeddingTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EmbeddingType.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    EMBEDDING_TYPE_UNSPECIFIED = EmbeddingType.V(0)
    EMBEDDING_TYPE_SPACY = EmbeddingType.V(1)
    EMBEDDING_TYPE_USE = EmbeddingType.V(2)
    EMBEDDING_TYPE_SBERT = EmbeddingType.V(3)

EMBEDDING_TYPE_UNSPECIFIED = EmbeddingType.V(0)
EMBEDDING_TYPE_SPACY = EmbeddingType.V(1)
EMBEDDING_TYPE_USE = EmbeddingType.V(2)
EMBEDDING_TYPE_SBERT = EmbeddingType.V(3)
global___EmbeddingType = EmbeddingType


class NlpConfig(google.protobuf.message.Message):
    """message ResetCacheRequest {
        repeated CacheType cache_types = 1;
    }
    message ResetCacheResponse {}

    enum CacheType {
        CACHE_TYPE_UNSPECIFIED = 0;
        CACHE_TYPE_SPACY = 1;
        CACHE_TYPE_EMBEDDINGS = 2;
        CACHE_TYPE_VECTORS = 3;
        CACHE_TYPE_SIMILARITIES = 4;
    }

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LANGUAGE_FIELD_NUMBER: builtins.int
    SPACY_MODEL_FIELD_NUMBER: builtins.int
    EMBEDDING_MODELS_FIELD_NUMBER: builtins.int
    SIMILARITY_METHOD_FIELD_NUMBER: builtins.int
    language: typing.Text = ...
    spacy_model: typing.Text = ...
    @property
    def embedding_models(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EmbeddingModel]: ...
    similarity_method: global___SimilarityMethod.V = ...
    def __init__(self,
        *,
        language : typing.Text = ...,
        spacy_model : typing.Text = ...,
        embedding_models : typing.Optional[typing.Iterable[global___EmbeddingModel]] = ...,
        similarity_method : global___SimilarityMethod.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"embedding_models",b"embedding_models",u"language",b"language",u"similarity_method",b"similarity_method",u"spacy_model",b"spacy_model"]) -> None: ...
global___NlpConfig = NlpConfig

class SimilaritiesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONFIG_FIELD_NUMBER: builtins.int
    TEXT_TUPLES_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> global___NlpConfig: ...
    @property
    def text_tuples(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TextTuple]: ...
    def __init__(self,
        *,
        config : typing.Optional[global___NlpConfig] = ...,
        text_tuples : typing.Optional[typing.Iterable[global___TextTuple]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"config",b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"config",b"config",u"text_tuples",b"text_tuples"]) -> None: ...
global___SimilaritiesRequest = SimilaritiesRequest

class SimilaritiesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SIMILARITIES_FIELD_NUMBER: builtins.int
    @property
    def similarities(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(self,
        *,
        similarities : typing.Optional[typing.Iterable[builtins.float]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"similarities",b"similarities"]) -> None: ...
global___SimilaritiesResponse = SimilaritiesResponse

class TextTuple(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT1_FIELD_NUMBER: builtins.int
    TEXT2_FIELD_NUMBER: builtins.int
    text1: typing.Text = ...
    text2: typing.Text = ...
    def __init__(self,
        *,
        text1 : typing.Text = ...,
        text2 : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"text1",b"text1",u"text2",b"text2"]) -> None: ...
global___TextTuple = TextTuple

class DocBinRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONFIG_FIELD_NUMBER: builtins.int
    TEXTS_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    NO_ATTRIBUTES_FIELD_NUMBER: builtins.int
    PIPES_FIELD_NUMBER: builtins.int
    NO_PIPES_FIELD_NUMBER: builtins.int
    EMBEDDING_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> global___NlpConfig: ...
    @property
    def texts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    no_attributes: builtins.bool = ...
    @property
    def pipes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    no_pipes: builtins.bool = ...
    @property
    def embedding_levels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___EmbeddingLevel.V]: ...
    def __init__(self,
        *,
        config : typing.Optional[global___NlpConfig] = ...,
        texts : typing.Optional[typing.Iterable[typing.Text]] = ...,
        attributes : typing.Optional[typing.Iterable[typing.Text]] = ...,
        no_attributes : builtins.bool = ...,
        pipes : typing.Optional[typing.Iterable[typing.Text]] = ...,
        no_pipes : builtins.bool = ...,
        embedding_levels : typing.Optional[typing.Iterable[global___EmbeddingLevel.V]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"config",b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"attributes",b"attributes",u"config",b"config",u"embedding_levels",b"embedding_levels",u"no_attributes",b"no_attributes",u"no_pipes",b"no_pipes",u"pipes",b"pipes",u"texts",b"texts"]) -> None: ...
global___DocBinRequest = DocBinRequest

class DocBinResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DOCBIN_FIELD_NUMBER: builtins.int
    docbin: builtins.bytes = ...
    def __init__(self,
        *,
        docbin : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"docbin",b"docbin"]) -> None: ...
global___DocBinResponse = DocBinResponse

class VectorsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONFIG_FIELD_NUMBER: builtins.int
    TEXTS_FIELD_NUMBER: builtins.int
    EMBEDDING_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> global___NlpConfig: ...
    @property
    def texts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    @property
    def embedding_levels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___EmbeddingLevel.V]: ...
    def __init__(self,
        *,
        config : typing.Optional[global___NlpConfig] = ...,
        texts : typing.Optional[typing.Iterable[typing.Text]] = ...,
        embedding_levels : typing.Optional[typing.Iterable[global___EmbeddingLevel.V]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"config",b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"config",b"config",u"embedding_levels",b"embedding_levels",u"texts",b"texts"]) -> None: ...
global___VectorsRequest = VectorsRequest

class VectorsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VECTORS_FIELD_NUMBER: builtins.int
    @property
    def vectors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VectorResponse]: ...
    def __init__(self,
        *,
        vectors : typing.Optional[typing.Iterable[global___VectorResponse]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"vectors",b"vectors"]) -> None: ...
global___VectorsResponse = VectorsResponse

class VectorResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DOCUMENT_FIELD_NUMBER: builtins.int
    TOKENS_FIELD_NUMBER: builtins.int
    SENTENCES_FIELD_NUMBER: builtins.int
    @property
    def document(self) -> global___Vector: ...
    @property
    def tokens(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Vector]: ...
    @property
    def sentences(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Vector]: ...
    def __init__(self,
        *,
        document : typing.Optional[global___Vector] = ...,
        tokens : typing.Optional[typing.Iterable[global___Vector]] = ...,
        sentences : typing.Optional[typing.Iterable[global___Vector]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"document",b"document"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"document",b"document",u"sentences",b"sentences",u"tokens",b"tokens"]) -> None: ...
global___VectorResponse = VectorResponse

class Vector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VECTOR_FIELD_NUMBER: builtins.int
    @property
    def vector(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(self,
        *,
        vector : typing.Optional[typing.Iterable[builtins.float]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"vector",b"vector"]) -> None: ...
global___Vector = Vector

class EmbeddingModel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MODEL_TYPE_FIELD_NUMBER: builtins.int
    MODEL_NAME_FIELD_NUMBER: builtins.int
    POOLING_FIELD_NUMBER: builtins.int
    model_type: global___EmbeddingType.V = ...
    model_name: typing.Text = ...
    pooling: global___Pooling.V = ...
    def __init__(self,
        *,
        model_type : global___EmbeddingType.V = ...,
        model_name : typing.Text = ...,
        pooling : global___Pooling.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"model_name",b"model_name",u"model_type",b"model_type",u"pooling",b"pooling"]) -> None: ...
global___EmbeddingModel = EmbeddingModel



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: arg_services/topic_modeling/v1/topic_modeling.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from arg_services.nlp.v1 import nlp_pb2 as arg__services_dot_nlp_dot_v1_dot_nlp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='arg_services/topic_modeling/v1/topic_modeling.proto',
  package='arg_services.topic_modeling.v1',
  syntax='proto3',
  serialized_options=b'\n1de.uni_trier.recap.arg_services.topic_modeling.v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3arg_services/topic_modeling/v1/topic_modeling.proto\x12\x1e\x61rg_services.topic_modeling.v1\x1a\x1d\x61rg_services/nlp/v1/nlp.proto\"R\n\rTopicsRequest\x12\x11\n\tdocuments\x18\x01 \x03(\t\x12.\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1e.arg_services.nlp.v1.NlpConfig\"\x80\x01\n\x0eTopicsResponse\x12\x37\n\x08outliers\x18\x01 \x01(\x0b\x32%.arg_services.topic_modeling.v1.Topic\x12\x35\n\x06topics\x18\x02 \x03(\x0b\x32%.arg_services.topic_modeling.v1.Topic\"K\n\x05Topic\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\x33\n\x05terms\x18\x02 \x03(\x0b\x32$.arg_services.topic_modeling.v1.Term\"#\n\x04Term\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\x32\x7f\n\x14TopicModelingService\x12g\n\x06Topics\x12-.arg_services.topic_modeling.v1.TopicsRequest\x1a..arg_services.topic_modeling.v1.TopicsResponseB3\n1de.uni_trier.recap.arg_services.topic_modeling.v1b\x06proto3'
  ,
  dependencies=[arg__services_dot_nlp_dot_v1_dot_nlp__pb2.DESCRIPTOR,])




_TOPICSREQUEST = _descriptor.Descriptor(
  name='TopicsRequest',
  full_name='arg_services.topic_modeling.v1.TopicsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='documents', full_name='arg_services.topic_modeling.v1.TopicsRequest.documents', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='arg_services.topic_modeling.v1.TopicsRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=200,
)


_TOPICSRESPONSE = _descriptor.Descriptor(
  name='TopicsResponse',
  full_name='arg_services.topic_modeling.v1.TopicsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='outliers', full_name='arg_services.topic_modeling.v1.TopicsResponse.outliers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topics', full_name='arg_services.topic_modeling.v1.TopicsResponse.topics', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=331,
)


_TOPIC = _descriptor.Descriptor(
  name='Topic',
  full_name='arg_services.topic_modeling.v1.Topic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='arg_services.topic_modeling.v1.Topic.count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terms', full_name='arg_services.topic_modeling.v1.Topic.terms', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=408,
)


_TERM = _descriptor.Descriptor(
  name='Term',
  full_name='arg_services.topic_modeling.v1.Term',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='arg_services.topic_modeling.v1.Term.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='arg_services.topic_modeling.v1.Term.score', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=445,
)

_TOPICSREQUEST.fields_by_name['config'].message_type = arg__services_dot_nlp_dot_v1_dot_nlp__pb2._NLPCONFIG
_TOPICSRESPONSE.fields_by_name['outliers'].message_type = _TOPIC
_TOPICSRESPONSE.fields_by_name['topics'].message_type = _TOPIC
_TOPIC.fields_by_name['terms'].message_type = _TERM
DESCRIPTOR.message_types_by_name['TopicsRequest'] = _TOPICSREQUEST
DESCRIPTOR.message_types_by_name['TopicsResponse'] = _TOPICSRESPONSE
DESCRIPTOR.message_types_by_name['Topic'] = _TOPIC
DESCRIPTOR.message_types_by_name['Term'] = _TERM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopicsRequest = _reflection.GeneratedProtocolMessageType('TopicsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOPICSREQUEST,
  '__module__' : 'arg_services.topic_modeling.v1.topic_modeling_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.topic_modeling.v1.TopicsRequest)
  })
_sym_db.RegisterMessage(TopicsRequest)

TopicsResponse = _reflection.GeneratedProtocolMessageType('TopicsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOPICSRESPONSE,
  '__module__' : 'arg_services.topic_modeling.v1.topic_modeling_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.topic_modeling.v1.TopicsResponse)
  })
_sym_db.RegisterMessage(TopicsResponse)

Topic = _reflection.GeneratedProtocolMessageType('Topic', (_message.Message,), {
  'DESCRIPTOR' : _TOPIC,
  '__module__' : 'arg_services.topic_modeling.v1.topic_modeling_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.topic_modeling.v1.Topic)
  })
_sym_db.RegisterMessage(Topic)

Term = _reflection.GeneratedProtocolMessageType('Term', (_message.Message,), {
  'DESCRIPTOR' : _TERM,
  '__module__' : 'arg_services.topic_modeling.v1.topic_modeling_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.topic_modeling.v1.Term)
  })
_sym_db.RegisterMessage(Term)


DESCRIPTOR._options = None

_TOPICMODELINGSERVICE = _descriptor.ServiceDescriptor(
  name='TopicModelingService',
  full_name='arg_services.topic_modeling.v1.TopicModelingService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=447,
  serialized_end=574,
  methods=[
  _descriptor.MethodDescriptor(
    name='Topics',
    full_name='arg_services.topic_modeling.v1.TopicModelingService.Topics',
    index=0,
    containing_service=None,
    input_type=_TOPICSREQUEST,
    output_type=_TOPICSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TOPICMODELINGSERVICE)

DESCRIPTOR.services_by_name['TopicModelingService'] = _TOPICMODELINGSERVICE

# @@protoc_insertion_point(module_scope)



import multiprocessing as mp
import traceback
import typing as t
from concurrent import futures
from operator import attrgetter

import grpc
from grpc_reflection.v1alpha import reflection


def handle_except(ex: Exception, ctx: grpc.ServicerContext) -> None:
    """Handler that can be called when handling an exception.

    It will pass the traceback to the gRPC client and abort the context.

    Args:
        ex: Exception that occured.
        ctx: Current gRPC context.
    """

    msg = "".join(traceback.TracebackException.from_exception(ex).format())
    ctx.abort(grpc.StatusCode.UNKNOWN, msg)


def require_any(
    attrs: t.Collection[str],
    obj: object,
    ctx: grpc.ServicerContext,
    parent: str = "request",
) -> None:
    """Verify that any of the required arguments are supplied by the client.

    If arguments are missing, the context will be aborted

    Args:
        attrs: Names of the required parameters.
        obj: Current request message (e.g., a subclass of google.protobuf.message.Message).
        ctx: Current gRPC context.
        parent: Name of the parent message. Only used to compose more helpful error.
    """
    func = attrgetter(*attrs)
    attr_result = func(obj)

    if len(attrs) == 1:
        attr_result = [attr_result]

    if not any(attr_result):
        ctx.abort(
            grpc.StatusCode.INVALID_ARGUMENT,
            f"The message '{parent}' requires the following attributes: {attrs}.",
        )


def require_all(
    attrs: t.Collection[str],
    obj: object,
    ctx: grpc.ServicerContext,
    parent: str = "request",
) -> None:
    """Verify that all required arguments are supplied by the client.

    If arguments are missing, the context will be aborted

    Args:
        attrs: Names of the required parameters.
        obj: Current request message (e.g., a subclass of google.protobuf.message.Message).
        ctx: Current gRPC context.
        parent: Name of the parent message. Only used to compose more helpful error.
    """
    func = attrgetter(*attrs)
    attr_result = func(obj)

    if len(attrs) == 1:
        attr_result = [attr_result]

    if not all(attr_result):
        ctx.abort(
            grpc.StatusCode.INVALID_ARGUMENT,
            f"The message '{parent}' requires the following attributes: {attrs}.",
        )


def require_all_repeated(
    key: str,
    attrs: t.Collection[str],
    obj: object,
    ctx: grpc.ServicerContext,
) -> None:
    """Verify that all required arguments are supplied by the client.

    If arguments are missing, the context will be aborted

    Args:
        key: Name of repeated attribute.
        attrs: Names of the required parameters.
        obj: Current request message (e.g., a subclass of google.protobuf.message.Message).
        ctx: Current gRPC context.
    """
    func = attrgetter(key)

    for item in func(obj):
        require_all(attrs, item, ctx, key)


def require_any_repeated(
    key: str,
    attrs: t.Collection[str],
    obj: object,
    ctx: grpc.ServicerContext,
) -> None:
    """Verify that any required arguments are supplied by the client.

    If arguments are missing, the context will be aborted

    Args:
        key: Name of repeated attribute.
        attrs: Names of the required parameters.
        obj: Current request message (e.g., a subclass of google.protobuf.message.Message).
        ctx: Current gRPC context.
    """
    func = attrgetter(key)

    for item in func(obj):
        require_any(attrs, item, ctx, key)


def forbid_all(
    attrs: t.Collection[str],
    obj: object,
    ctx: grpc.ServicerContext,
    parent: str = "request",
) -> None:
    """Verify that no illegal combination of arguments is provided by the client.

    Args:
        attrs: Names of parameters which cannot occur at the same time.
        obj: Current request message (e.g., a subclass of google.protobuf.message.Message).
        ctx: Current gRPC context.
        parent: Name of the parent message. Only used to compose more helpful error.
    """
    func = attrgetter(*attrs)
    attr_result = func(obj)

    if len(attrs) == 1:
        attr_result = [attr_result]

    if all(attr_result):
        ctx.abort(
            grpc.StatusCode.INVALID_ARGUMENT,
            f"The message '{parent}' is not allowed to allowed to have the following parameter combination: {attrs}.",
        )


def full_service_name(pkg, service: str) -> str:
    return pkg.DESCRIPTOR.services_by_name[service].full_name


def _serve_single(
    bind_address: str,
    add_services: t.Callable[[grpc.Server], None],
    threads: int,
    reflection_services: t.Iterable[str] = tuple(),
    current_process: int = 1,
    total_processes: int = 1,
):
    """Helper function to start a server for a single process.

    Args:
        bind_address: Complete address consisting of hostname and port (e.g., `127.0.0.1:8000`)
        add_services: Function to inject the gRPC services into the server instance.
        current_process: Number of current process.
        total_processes: Total number of spawned processes.
    """
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=threads))
    add_services(server)

    if reflection_services:
        reflection.enable_server_reflection(
            [*reflection_services, reflection.SERVICE_NAME], server
        )

    server.add_insecure_port(bind_address)
    server.start()

    print(f"Worker {current_process}/{total_processes} serving on '{bind_address}'.")

    server.wait_for_termination()


def serve(
    host: str,
    port: int,
    add_services: t.Callable[[grpc.Server], None],
    threads: int = 1,
    processes: int = 1,
    reflection_services: t.Iterable[str] = tuple(),
):
    """Serve one or multiple gRPC services, optionally using multiprocessing.

    Args:
        host: Hostname of the server (e.g., `127.0.0.1`)
        ports: Start port for the server.
            Use `0` to let the server determine an open port.
        add_services: Function to inject the gRPC services into the server instance.
        threads: Number of workers in the gRPC thread pool.
        processes: Number of individual servers (each with their own port).

    Raises:
        ValueError: If `processes < 1` is given.
    """

    if processes < 1:
        raise ValueError("At least one process is required.")
    elif processes == 1:
        bind_addr = f"{host}:{port}"
        print(f"Connect to 'ipv4:{bind_addr}'.")

        _serve_single(bind_addr, add_services, threads, reflection_services)
    else:
        workers = []
        addresses = []

        for i, port in enumerate(range(port, port + processes)):
            bind_addr = f"{host}:{port}"
            addresses.append(bind_addr)

            worker = mp.Process(
                target=_serve_single,
                args=(
                    bind_addr,
                    add_services,
                    reflection_services,
                    i + 1,
                    processes,
                ),
            )
            worker.start()
            workers.append(worker)

        bind_addr = ",".join(addresses)
        print(f"Connect to 'ipv4:{bind_addr}'.")

        for worker in workers:
            worker.join()
